@@ -13,7 +13,7 @@ class FakeData(VisionDataset):
         size (int, optional): Size of the dataset. Default: 1000 images
         image_size(tuple, optional): Size if the returned images. Default: (3, 224, 224)
         num_classes(int, optional): Number of classes in the dataset. Default: 10
-        transform (callable, optional): A function/transform that  takes in an PIL image
+        transform (callable, optional): A function/transform that takes in a PIL image
             and returns a transformed version. E.g, ``transforms.RandomCrop``
         target_transform (callable, optional): A function/transform that takes in the
             target and transforms it.
@@ -31,7 +31,7 @@ class FakeData(VisionDataset):
         target_transform: Optional[Callable] = None,
         random_offset: int = 0,
     ) -> None:
-        super().__init__(None, transform=transform, target_transform=target_transform)  # type: ignore[arg-type]
+        super().__init__(transform=transform, target_transform=target_transform)
         self.size = size
         self.num_classes = num_classes
         self.image_size = image_size
