@@ -1,22 +1,21 @@
 import csv
 import os
-import time
 import urllib
-import warnings
 from functools import partial
 from multiprocessing import Pool
 from os import path
-from typing import Any, Callable, Dict, Optional, Tuple
+from pathlib import Path
+from typing import Any, Callable, Dict, Optional, Tuple, Union
 
 from torch import Tensor
 
 from .folder import find_classes, make_dataset
-from .utils import download_and_extract_archive, download_url, verify_str_arg, check_integrity
+from .utils import check_integrity, download_and_extract_archive, download_url, verify_str_arg
 from .video_utils import VideoClips
 from .vision import VisionDataset
 
 
-def _dl_wrap(tarpath: str, videopath: str, line: str) -> None:
+def _dl_wrap(tarpath: Union[str, Path], videopath: Union[str, Path], line: str) -> None:
     download_and_extract_archive(line, tarpath, videopath)
 
 
@@ -36,19 +35,19 @@ class Kinetics(VisionDataset):
     frames in a video might be present.
 
     Args:
-        root (string): Root directory of the Kinetics Dataset.
+        root (str or ``pathlib.Path``): Root directory of the Kinetics Dataset.
             Directory should be structured as follows:
             .. code::
 
                 root/
                 ├── split
                 │   ├──  class1
-                │   │   ├──  clip1.mp4
-                │   │   ├──  clip2.mp4
-                │   │   ├──  clip3.mp4
+                │   │   ├──  vid1.mp4
+                │   │   ├──  vid2.mp4
+                │   │   ├──  vid3.mp4
                 │   │   ├──  ...
                 │   ├──  class2
-                │   │   ├──   clipx.mp4
+                │   │   ├──   vidx.mp4
                 │   │    └── ...
 
             Note: split is appended automatically using the split argument.
@@ -57,7 +56,7 @@ class Kinetics(VisionDataset):
         split (str): split of the dataset to consider; supports ``"train"`` (default) ``"val"`` ``"test"``
         frame_rate (float): If omitted, interpolate different frame rate for each clip.
         step_between_clips (int): number of frames between each clip
-        transform (callable, optional): A function/transform that  takes in a TxHxWxC video
+        transform (callable, optional): A function/transform that takes in a TxHxWxC video
             and returns a transformed version.
         download (bool): Download the official version of the dataset to root folder.
         num_workers (int): Use multiple workers for VideoClips creation
@@ -91,7 +90,7 @@ class Kinetics(VisionDataset):
 
     def __init__(
         self,
-        root: str,
+        root: Union[str, Path],
         frames_per_clip: int,
         num_classes: str = "400",
         split: str = "train",
@@ -121,7 +120,6 @@ class Kinetics(VisionDataset):
         self._legacy = _legacy
 
         if _legacy:
-            print("Using legacy structure")
             self.split_folder = root
             self.split = "unknown"
             output_format = "THWC"
@@ -157,14 +155,8 @@ class Kinetics(VisionDataset):
 
     def download_and_process_videos(self) -> None:
         """Downloads all the videos to the _root_ folder in the expected format."""
-        tic = time.time()
         self._download_videos()
-        toc = time.time()
-        print("Elapsed time for downloading in mins ", (toc - tic) / 60)
         self._make_ds_structure()
-        toc2 = time.time()
-        print("Elapsed time for processing in mins ", (toc2 - toc) / 60)
-        print("Elapsed time overall in mins ", (toc2 - tic) / 60)
 
     def _download_videos(self) -> None:
         """download tarballs containing the video to "tars" folder and extract them into the _split_ folder where
@@ -174,10 +166,7 @@ class Kinetics(VisionDataset):
             RuntimeError: if download folder exists, break to prevent downloading entire dataset again.
         """
         if path.exists(self.split_folder):
-            raise RuntimeError(
-                f"The directory {self.split_folder} already exists. "
-                f"If you want to re-download or re-extract the images, delete the directory."
-            )
+            return
         tar_path = path.join(self.root, "tars")
         file_list_path = path.join(self.root, "files")
 
@@ -246,83 +235,3 @@ class Kinetics(VisionDataset):
             video = self.transform(video)
 
         return video, audio, label
-
-
-class Kinetics400(Kinetics):
-    """
-    `Kinetics-400 <https://deepmind.com/research/open-source/open-source-datasets/kinetics/>`_
-    dataset.
-
-    .. warning::
-        This class was deprecated in ``0.12`` and will be removed in ``0.14``. Please use
-        ``Kinetics(..., num_classes='400')`` instead.
-
-    Kinetics-400 is an action recognition video dataset.
-    This dataset consider every video as a collection of video clips of fixed size, specified
-    by ``frames_per_clip``, where the step in frames between each clip is given by
-    ``step_between_clips``.
-
-    To give an example, for 2 videos with 10 and 15 frames respectively, if ``frames_per_clip=5``
-    and ``step_between_clips=5``, the dataset size will be (2 + 3) = 5, where the first two
-    elements will come from video 1, and the next three elements from video 2.
-    Note that we drop clips which do not have exactly ``frames_per_clip`` elements, so not all
-    frames in a video might be present.
-
-    Internally, it uses a VideoClips object to handle clip creation.
-
-    Args:
-        root (string): Root directory of the Kinetics-400 Dataset. Should be structured as follows:
-
-            .. code::
-
-                root/
-                ├── class1
-                │   ├── clip1.avi
-                │   ├── clip2.avi
-                │   ├── clip3.mp4
-                │   └── ...
-                └── class2
-                    ├── clipx.avi
-                    └── ...
-
-        frames_per_clip (int): number of frames in a clip
-        step_between_clips (int): number of frames between each clip
-        transform (callable, optional): A function/transform that  takes in a TxHxWxC video
-            and returns a transformed version.
-
-    Returns:
-        tuple: A 3-tuple with the following entries:
-
-            - video (Tensor[T, H, W, C]): the `T` video frames
-            - audio(Tensor[K, L]): the audio frames, where `K` is the number of channels
-              and `L` is the number of points
-            - label (int): class of the video clip
-    """
-
-    def __init__(
-        self,
-        root: str,
-        frames_per_clip: int,
-        num_classes: Any = None,
-        split: Any = None,
-        download: Any = None,
-        num_download_workers: Any = None,
-        **kwargs: Any,
-    ) -> None:
-        warnings.warn(
-            "The Kinetics400 class is deprecated since 0.12 and will be removed in 0.14."
-            "Please use Kinetics(..., num_classes='400') instead."
-            "Note that Kinetics(..., num_classes='400') returns video in a Tensor[T, C, H, W] format."
-        )
-        if any(value is not None for value in (num_classes, split, download, num_download_workers)):
-            raise RuntimeError(
-                "Usage of 'num_classes', 'split', 'download', or 'num_download_workers' is not supported in "
-                "Kinetics400. Please use Kinetics instead."
-            )
-
-        super().__init__(
-            root=root,
-            frames_per_clip=frames_per_clip,
-            _legacy=True,
-            **kwargs,
-        )
