@@ -3,6 +3,7 @@ import os.path
 import pickle
 import string
 from collections.abc import Iterable
+from pathlib import Path
 from typing import Any, Callable, cast, List, Optional, Tuple, Union
 
 from PIL import Image
@@ -54,16 +55,16 @@ class LSUNClass(VisionDataset):
 
 
 class LSUN(VisionDataset):
-    """`LSUN <https://www.yf.io/p/lsun>`_ dataset.
+    """`LSUN <https://paperswithcode.com/dataset/lsun>`_ dataset.
 
     You will need to install the ``lmdb`` package to use this dataset: run
     ``pip install lmdb``
 
     Args:
-        root (string): Root directory for the database files.
+        root (str or ``pathlib.Path``): Root directory for the database files.
         classes (string or list): One of {'train', 'val', 'test'} or a list of
             categories to load. e,g. ['bedroom_train', 'church_outdoor_train'].
-        transform (callable, optional): A function/transform that  takes in an PIL image
+        transform (callable, optional): A function/transform that takes in a PIL image
             and returns a transformed version. E.g, ``transforms.RandomCrop``
         target_transform (callable, optional): A function/transform that takes in the
             target and transforms it.
@@ -71,7 +72,7 @@ class LSUN(VisionDataset):
 
     def __init__(
         self,
-        root: str,
+        root: Union[str, Path],
         classes: Union[str, List[str]] = "train",
         transform: Optional[Callable] = None,
         target_transform: Optional[Callable] = None,
