@@ -1,15 +1,11 @@
 from typing import Any, Dict
 
-from torchvision import datapoints
+import torch
 from torchvision.transforms.v2 import functional as F, Transform
 
-from torchvision.transforms.v2.utils import is_simple_tensor
-
 
 class UniformTemporalSubsample(Transform):
-    """[BETA] Uniformly subsample ``num_samples`` indices from the temporal dimension of the video.
-
-    .. v2betastatus:: UniformTemporalSubsample transform
+    """Uniformly subsample ``num_samples`` indices from the temporal dimension of the video.
 
     Videos are expected to be of shape ``[..., T, C, H, W]`` where ``T`` denotes the temporal dimension.
 
@@ -20,11 +16,11 @@ class UniformTemporalSubsample(Transform):
         num_samples (int): The number of equispaced samples to be selected
     """
 
-    _transformed_types = (is_simple_tensor, datapoints.Video)
+    _transformed_types = (torch.Tensor,)
 
     def __init__(self, num_samples: int):
         super().__init__()
         self.num_samples = num_samples
 
-    def _transform(self, inpt: datapoints._VideoType, params: Dict[str, Any]) -> datapoints._VideoType:
-        return F.uniform_temporal_subsample(inpt, self.num_samples)
+    def transform(self, inpt: Any, params: Dict[str, Any]) -> Any:
+        return self._call_kernel(F.uniform_temporal_subsample, inpt, self.num_samples)
